dartantic_interface library

Classes

BatchEmbeddingsResult
Result for batch embeddings operations.
ChatMessage
A chat message.
ChatModel<TOptions extends ChatModelOptions>
Chat model base class.
ChatModelOptions
Generation options to pass into the Chat Model.
ChatResult<T extends Object>
Result returned by the Chat Model.
DataPart
A data part containing binary data (e.g., images).
EmbeddingsModel<TOptions extends EmbeddingsModelOptions>
Embeddings model base class.
EmbeddingsModelOptions
Base class for embeddings model options.
EmbeddingsResult
Result returned by embeddings providers.
LanguageModelResult<TOutput extends Object>
Result returned by the model.
LanguageModelUsage
Usage stats for the generation.
LinkPart
A link part referencing external content.
MediaGenerationModel<TOptions extends MediaGenerationModelOptions>
Base class for media generation models.
MediaGenerationModelOptions
Base class for media generation model options.
MediaGenerationResult
Streaming chunk returned by a media generation model.
ModelInfo
Model metadata for provider model listing.
PartHelpers
Helper utilities for Part-related operations.
Provider<TChatOptions extends ChatModelOptions, TEmbeddingsOptions extends EmbeddingsModelOptions, TMediaOptions extends MediaGenerationModelOptions>
Provides a unified interface for accessing all major LLM, chat, and embedding providers in dartantic_ai.
StandardPart
Base class for parts that became de-facto standard for AI messages.
TextPart
A text part of a message.
ThinkingPart
A "thinking" part of a message, used by some models to show reasoning.
Tool<TInput extends Object>
A tool that can be called by the LLM.
ToolPart
A tool interaction part of a message.

Enums

ChatMessageRole
The role of a message author.
FinishReason
The reason the model stopped generating tokens.
ModelKind
The kind of model supported by a provider.
ToolPartKind
The kind of tool interaction.

Extension Types

Schema
A JSON Schema object defining any kind of property.

Extensions

MessagePartHelpers on Iterable<Part>
Static helper methods for extracting specific types of parts from a list.

Typedefs

Part = StandardPart
Alias for StandardPart for API convenience.
S = Schema
A shortcut typedef so that Schema.object, etc. can be used as S.object.