BatchEmbeddingsResult class

Result for batch embeddings operations.

Inheritance

Constructors

BatchEmbeddingsResult({required List<List<double>> output, required FinishReason finishReason, required Map<String, dynamic> metadata, required LanguageModelUsage? usage, String? id})
Creates a new batch embeddings result instance.

Properties

count int
Number of embeddings in the batch.
no setter
dimensions int
Dimensions of each embedding vector.
no setter
embeddings List<List<double>>
The batch of embedding vectors.
no setter
finishReason FinishReason
The reason the model stopped generating tokens.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Result id.
finalinherited
metadata Map<String, dynamic>
Other metadata about the generation.
finalinherited
output List<List<double>>
Generated output.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage LanguageModelUsage?
Usage stats for the generation.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited