ModelKind enum

The kind of model supported by a provider.

Used to classify models for listing, filtering, and selection.

  • chat: Chat completion models for conversational AI
  • image: Image generation or vision models
  • embeddings: Text embedding models for semantic similarity
  • audio: Audio processing models (speech-to-text, etc.)
  • tts: Text-to-speech models
  • countTokens: Count the number of tokens in a text string
  • other: Other specialized model types
Inheritance
Available extensions

Values

chat → const ModelKind

Chat completion models for conversational AI

media → const ModelKind

Unified media generation models (images, documents, audio, etc.)

image → const ModelKind

Image generation or vision models

video → const ModelKind

Video generation models

embeddings → const ModelKind

Text embedding models for semantic similarity

audio → const ModelKind

Audio processing models (speech-to-text, etc.)

tts → const ModelKind

Text-to-speech models

countTokens → const ModelKind

Count the number of tokens in a text string

other → const ModelKind

Other specialized model types

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ModelKind>
A constant List of the values in this enum, in order of their declaration.