Schema.boolean constructor
Creates a JSON Schema definition for a bool.
See also:
BooleanSchemafor the class that this factory constructor delegates to.
Implementation
factory Schema.boolean({String? title, String? description}) = BooleanSchema;
Creates a JSON Schema definition for a bool.
See also:
BooleanSchema for the class that this factory constructor delegates
to.factory Schema.boolean({String? title, String? description}) = BooleanSchema;