ChatModel<TOptions extends ChatModelOptions> class
abstract
Chat model base class.
Constructors
Properties
- defaultOptions → TOptions
-
The default options for the chat model.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The model name to use.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temperature → double?
-
The temperature for the model.
final
-
tools
→ List<
Tool< ?Object> > -
The tools the model may call.
final
Methods
-
dispose(
) → void - Disposes the chat model.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendStream(
List< ChatMessage> messages, {TOptions? options, Schema? outputSchema}) → Stream<ChatResult< ChatMessage> > - Streaming method that returns Message objects.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited