thinking property
Thinking content for real-time streaming display (for reasoning models).
During streaming, this field contains incremental thinking deltas as they arrive from the model. The final consolidated thinking is available in the message's ThinkingPart.
Implementation
final String? thinking;