EmbeddingsModelOptions class
Base class for embeddings model options.
Constructors
- EmbeddingsModelOptions({int? dimensions, int? batchSize})
-
Creates a new embeddings model options instance.
const
Properties
- batchSize → int?
-
The maximum number of texts to embed in a single request.
final
- dimensions → int?
-
The number of dimensions the resulting output embeddings should have.
Only supported by some models.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited