ModelInfo class
Model metadata for provider model listing.
Returned by Provider.listModels for all providers. Contains the model id, kind, name, description, and any extra metadata.
Constructors
Properties
- description → String?
-
A description of the model, if available.
final
- displayName → String?
-
The display name of the model, if available.
final
-
extra
→ Map<
String, dynamic> -
Any extra metadata returned by the provider.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kinds
→ Set<
ModelKind> -
The set of kinds of model (chat, embedding, media, etc). Must not be
empty.
final
- model → String
-
The full model name, including the provider name.
no setter
- name → String
-
The unique name for the model (required).
final
- providerName → String
-
The name of the provider that provides the model.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited