PartHelpers class
Helper utilities for Part-related operations.
Provides MIME type detection and file extension mapping for DataPart.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
extensionFromMimeType(
String mimeType) → String? - Gets the extension for a MIME type.
-
mimeType(
String path, {Uint8List? headerBytes}) → String - Gets the MIME type for a file.
-
nameFromMimeType(
String mimeType) → String - Gets the name for a MIME type.
Constants
- defaultMimeType → const String
- The default MIME type for binary data.